@@ -17,14 +17,17 @@
 #include "utils_interface.h"
 #include <target/utils.hpp>
 #include <target/glm.hpp>
+#include <target/pava.hpp>
+
+using namespace Rcpp;
 
 
 // [[Rcpp::export(name=".clusterid")]]
-Rcpp::List clusterid(const arma::uvec &id) {
+List clusterid(const arma::uvec &id) {
   arma::umat res = target::clusterid(id);
-  return Rcpp::List::create(Rcpp::Named("size")=res.col(1),
-			    Rcpp::Named("idx")=res.col(0)+1,
-			    Rcpp::Named("n")=res.n_rows);
+  return List::create(Named("size")=res.col(1),
+		      Named("idx")=res.col(0)+1,
+		      Named("n")=res.n_rows);
 }
 
 // [[Rcpp::export(name=".groupsum")]]
@@ -39,3 +42,13 @@ arma::mat groupsum(const arma::mat &x,
 arma::mat softmax(arma::mat &lp, bool ref=true, bool log=false) {
   return target::softmax(lp, ref, log);
 }
+
+// [[Rcpp::export(name = ".pava")]]
+List pava(const arma::vec &y, const NumericVector &x, const NumericVector &weights) {
+  arma::mat res = target::pava(y, x, weights);
+  NumericVector idx = Rcpp::wrap(res.col(1)+1);
+  idx.attr("dim") = R_NilValue;
+  return Rcpp::List::create(Rcpp::Named("index")=idx,
+			    Rcpp::Named("value")=res.col(0));
+
+}
